@@ -63,10 +63,14 @@
               # acol <- unname(ct) ## TODO new column $amount_col for $amount
               # res$z <- factor(names(ct)[res$z+1L]) ## -- 20180317
                res$z <- ordered(factor(names(ct)[res$z+1L]),levels=names(ct)) ## ++ 20180317
+               if (T)
+                  attr(res$z,"colortable") <- ct
             }
             if (length(indZ)>0) ## 20160812 changed '>1' -> '>0'
                colnames(res)[i+2] <- bname[i]
          }
+         if (F & isCT)
+            attr(res,"colortable") <- ct
       }
       else if (FALSE){
         # res <- cbind(xy,as.data.frame(obj$value[indR,indZ])) ## not quick
