@@ -33,8 +33,8 @@
    }
    dim(z) <- with(g1,c(columns,rows))
    z <- z[,rev(seq(g1$rows)),drop=FALSE]
-   img <- list(x=xo,y=yo,z=z)#,nodata=ignorevalue(x),proj=proj4[length(proj4)])
-   attr(img,"proj4") <- with(g1,proj4[length(proj4)])
+   img <- list(x=xo,y=yo,z=z)#,nodata=ignorevalue(x),crs=proj4[length(proj4)])
+   attr(img,"crs") <- with(g1,crs[length(crs)])
    if (length(x$colortable))
       attr(img,"colortable") <- x$colortable
    img
