@@ -27,7 +27,7 @@
       isSF <- requireNamespace("sf",quietly=.isPackageInUse())
       isSP <- !isSF
    }
-   else {
+   else if (F) { ## deprecated 'rgdal'
       loaded <- loadedNamespaces() #.loaded()
       if (any(c("sf","geojsonsf") %in% loaded))
          isSF <- TRUE
@@ -37,6 +37,10 @@
          isSF <- requireNamespace("sf",quietly=.isPackageInUse())
       isSP <- !isSF
    }
+   else {
+      isSF <- requireNamespace("sf",quietly=.isPackageInUse())
+      isSP <- !isSF
+   }
    jsonSF <- FALSE
    if ((length(crs))&&("auto" %in% style))
       style <- .epsg2proj4(crs)
@@ -68,6 +72,9 @@
       }
    }
    proj4 <- NULL
+   if ((!(style %in% c("auto","keep")))&&(isFALSE(resetProj))) { ## ++20230612
+      resetProj <- TRUE
+   }
    if (!((is.character(dsn))&&(length(dsn)==1))) {
       nextCheck <- TRUE
       if ((.isSF(dsn))||(.isSP(dsn))) {
@@ -1250,7 +1257,7 @@
          if (verbose)
             print(data.frame(lon0=lon_0,lat0=lat_0,lat_ts=lat_ts,row.names=proj))
          if (proj=="stere") {
-            t_srs <- paste("","+proj=stere"
+            t_srs <- paste("+proj=stere"
                           ,paste0("+lat_0=",lat_0)
                           ,paste0("+lat_ts=",lat_ts)
                           ,paste0("+lon_0=",lon_0)
@@ -1269,7 +1276,7 @@
                lon_0[lon_0>=(-25) && lon_0<(+50)] <- 10
                lon_0[lon_0>=(50) && lon_0<(+135)] <- 90
             }
-            t_srs <- paste("","+proj=laea"
+            t_srs <- paste("+proj=laea"
                           ,paste0("+lat_0=",lat_0)
                           ,paste0("+lon_0=",lon_0)
                           ,"+k=1","+x_0=0 +y_0=0 +datum=WGS84 +units=m +no_defs")
